
var scale = 1

var smallSpacing = 7 * scale
var largeSpacing = smallSpacing * 2

var switcherWidth = 90 * scale
var headerHeight = 56 * scale

var listItemHeight = 70 * scale
var iconSize = 36 * scale

var fadeHeight = 26 * scale

var quickTransition = 50
var slowTransition = 150
var fadeTransition = 300

var selectColor = '#a07f5785' /* gpodder purple */
var downloadColor = '#a08ae234' /* download green */
var playbackColor = '#a0729fcf' /* playback blue */

var baseColor = '#2b2b2b'
var offlineColor = '#4b4b4b'

var hasCloseButton = false
var hasTaskSwitcher = false

var listItemBigText = listItemHeight * .35
var listItemSmallText = listItemHeight * .25

